Class: Fastlane::Helper::ReactNativeUtilHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::ReactNativeUtilHelper
- Defined in:
- lib/fastlane/plugin/react_native_util/helper/react_native_util_helper.rb
Class Method Summary collapse
-
.show_message ⇒ Object
class methods that you define here become available in your action as
Helper::ReactNativeUtilHelper.your_method.
Class Method Details
.show_message ⇒ Object
class methods that you define here become available in your action as Helper::ReactNativeUtilHelper.your_method
11 12 13 |
# File 'lib/fastlane/plugin/react_native_util/helper/react_native_util_helper.rb', line 11 def self. UI.("Hello from the react_native_util plugin helper!") end |